@@ -1,15 +1,6 @@
 """Retain apiclient as an alias for googleapiclient."""
 
-from six import iteritems
-
-import googleapiclient
-
-from googleapiclient import channel
-from googleapiclient import discovery
-from googleapiclient import errors
-from googleapiclient import http
-from googleapiclient import mimeparse
-from googleapiclient import model
+from googleapiclient import channel, discovery, errors, http, mimeparse, model
 
 try:
     from googleapiclient import sample_tools
@@ -19,8 +10,6 @@ except ImportError:
     sample_tools = None
 from googleapiclient import schema
 
-__version__ = googleapiclient.__version__
-
 _SUBMODULES = {
     "channel": channel,
     "discovery": discovery,
@@ -34,5 +23,5 @@ _SUBMODULES = {
 
 import sys
 
-for module_name, module in iteritems(_SUBMODULES):
+for module_name, module in _SUBMODULES.items():
     sys.modules["apiclient.%s" % module_name] = module
